@@ -39,15 +39,13 @@ from autonomy.cli.fetch import fetch_service
 from autonomy.cli.utils.click_utils import chain_selection_flag
 from autonomy.configurations.constants import DEFAULT_SERVICE_FILE
 from autonomy.configurations.loader import load_service_config
-from autonomy.constants import DEFAULT_IMAGE_VERSION, DEFAULT_KEYS_FILE
-from autonomy.data import DATA_DIR
+from autonomy.constants import DEFAULT_KEYS_FILE
 from autonomy.deploy.build import generate_deployment
 from autonomy.deploy.chain import ServiceRegistry
 from autonomy.deploy.constants import (
     AGENT_KEYS_DIR,
     BENCHMARKS_DIR,
     DEFAULT_ABCI_BUILD_DIR,
-    DOCKERFILES,
     INFO,
     LOGGING_LEVELS,
     LOG_DIR,
@@ -57,7 +55,7 @@ from autonomy.deploy.constants import (
 )
 from autonomy.deploy.generators.docker_compose.base import DockerComposeGenerator
 from autonomy.deploy.generators.kubernetes.base import KubernetesGenerator
-from autonomy.deploy.image import ImageProfiles, build_image
+from autonomy.deploy.image import build_image
 
 
 @click.group(name="deploy")
@@ -103,11 +101,6 @@ def deploy_group(
     default=False,
     help="Create development environment.",
 )
-@click.option(
-    "--version",
-    "version",
-    help="Specify deployment version.",
-)
 @click.option(
     "--force",
     "force_overwrite",
@@ -147,7 +140,6 @@ def build_deployment_command(  # pylint: disable=too-many-arguments, too-many-lo
     registry: str,
     number_of_agents: Optional[int] = None,
     password: Optional[str] = None,
-    version: Optional[str] = None,
     open_aea_dir: Optional[Path] = None,
     packages_dir: Optional[Path] = None,
     open_autonomy_dir: Optional[Path] = None,
@@ -175,7 +167,6 @@ def build_deployment_command(  # pylint: disable=too-many-arguments, too-many-lo
             force_overwrite,
             number_of_agents,
             password,
-            version,
             packages_dir,
             open_aea_dir,
             open_autonomy_dir,
@@ -220,9 +211,7 @@ def run(build_dir: Path, no_recreate: bool, remove_orphans: bool) -> None:
     help="Service contract address for custom RPC URL.",
 )
 @click.option("--n", type=int, help="Number of agents to include in the build.")
-@click.option(
-    "--skip-images", is_flag=True, default=False, help="Skip building images."
-)
+@click.option("--skip-image", is_flag=True, default=False, help="Skip building images.")
 @chain_selection_flag()
 @click.pass_context
 def run_deployment_from_token(  # pylint: disable=too-many-arguments, too-many-locals
@@ -232,7 +221,7 @@ def run_deployment_from_token(  # pylint: disable=too-many-arguments, too-many-l
     chain_type: str,
     rpc_url: Optional[str],
     service_contract_address: Optional[str],
-    skip_images: bool,
+    skip_image: bool,
     n: Optional[int],
 ) -> None:
     """Run service deployment."""
@@ -257,22 +246,9 @@ def run_deployment_from_token(  # pylint: disable=too-many-arguments, too-many-l
     service = load_service_config(service_path)
 
     with cd(service_path):
-        if not skip_images:
+        if not skip_image:
             click.echo("Building required images.")
-            build_image(
-                agent=service.agent,
-                profile=ImageProfiles.PRODUCTION,
-                skaffold_dir=DATA_DIR / DOCKERFILES,
-                version=DEFAULT_IMAGE_VERSION,
-                push=False,
-            )
-            build_image(
-                agent=service.agent,
-                profile=ImageProfiles.DEPENDENCIES,
-                skaffold_dir=DATA_DIR / DOCKERFILES,
-                version=DEFAULT_IMAGE_VERSION,
-                push=False,
-            )
+            build_image(agent=service.agent)
 
         build_deployment(
             keys_file,
@@ -281,7 +257,6 @@ def run_deployment_from_token(  # pylint: disable=too-many-arguments, too-many-l
             dev_mode=False,
             force_overwrite=True,
             number_of_agents=n,
-            version=DEFAULT_IMAGE_VERSION,
             agent_instances=agent_instances,
         )
 
@@ -315,7 +290,6 @@ def build_deployment(  # pylint: disable=too-many-arguments
     force_overwrite: bool,
     number_of_agents: Optional[int] = None,
     password: Optional[str] = None,
-    version: Optional[str] = None,
     packages_dir: Optional[Path] = None,
     open_aea_dir: Optional[Path] = None,
     open_autonomy_dir: Optional[Path] = None,
@@ -340,7 +314,6 @@ def build_deployment(  # pylint: disable=too-many-arguments
         number_of_agents=number_of_agents,
         build_dir=build_dir,
         dev_mode=dev_mode,
-        version=version,
         packages_dir=packages_dir,
         open_aea_dir=open_aea_dir,
         open_autonomy_dir=open_autonomy_dir,
