@@ -22,12 +22,21 @@ import os
 
 DEFAULT_BUILD_FOLDER = "abci_build"
 DEFAULT_KEYS_FILE = "keys.json"
-DEFAULT_IMAGE_VERSION = "0.1.0"
-IMAGE_VERSION = os.environ.get("VERSION", DEFAULT_IMAGE_VERSION)
+DEFAULT_IMAGE_VERSION = "latest"
+
+AUTONOMY_IMAGE_VERSION = os.environ.get("AUTONOMY_IMAGE_VERSION", DEFAULT_IMAGE_VERSION)
 TENDERMINT_IMAGE_VERSION = os.environ.get(
     "TENDERMINT_IMAGE_VERSION", DEFAULT_IMAGE_VERSION
 )
 HARDHAT_IMAGE_VERSION = os.environ.get("HARDHAT_IMAGE_VERSION", DEFAULT_IMAGE_VERSION)
-OPEN_AEA_IMAGE_NAME = "valory/open-autonomy-open-aea"
-TENDERMINT_IMAGE_NAME = "valory/open-autonomy-tendermint"
-HARDHAT_IMAGE_NAME = "valory/open-autonomy-hardhat"
+
+AUTONOMY_IMAGE_NAME = os.environ.get("AUTONOMY_IMAGE_NAME", "valory/open-autonomy")
+TENDERMINT_IMAGE_NAME = os.environ.get(
+    "TENDERMINT_IMAGE_NAME", "valory/open-autonomy-tendermint"
+)
+HARDHAT_IMAGE_NAME = os.environ.get(
+    "HARDHAT_IMAGE_NAME", "valory/open-autonomy-hardhat"
+)
+
+OAR_IMAGE = "valory/oar-{agent}:{version}"
+ABSTRACT_ROUND_ABCI_SKILL_WITH_HASH = "valory/abstract_round_abci:0.1.0:bafybeiayewfb2ytovp7exhawqwbw63eerx4tw53ztey5r4ozbtcvsw3gua"
