@@ -35,7 +35,7 @@ from packaging.version import Version
 from py_eth_sig_utils.eip712 import encode_typed_data
 from requests import HTTPError
 from web3.exceptions import SolidityError, TransactionNotFound
-from web3.types import Nonce, TxData, TxParams, Wei
+from web3.types import BlockIdentifier, Nonce, TxData, TxParams, Wei
 
 from packages.valory.contracts.gnosis_safe_proxy_factory.contract import (
     GnosisSafeProxyFactoryContract,
@@ -130,7 +130,7 @@ class GnosisSafeContract(Contract):
         owners: List[str],
         threshold: int,
         salt_nonce: Optional[int] = None,
-        gas: Optional[int] = None,
+        gas: int = 0,
         gas_price: Optional[int] = None,
         max_fee_per_gas: Optional[int] = None,
         max_priority_fee_per_gas: Optional[int] = None,
@@ -383,6 +383,7 @@ class GnosisSafeContract(Contract):
         max_fee_per_gas: Optional[int] = None,
         max_priority_fee_per_gas: Optional[int] = None,
         old_price: Optional[Dict[str, Wei]] = None,
+        fallback_gas: int = 0,
     ) -> JSONLike:
         """
         Get the raw Safe transaction
@@ -407,6 +408,7 @@ class GnosisSafeContract(Contract):
         :param max_fee_per_gas: max
         :param max_priority_fee_per_gas: max
         :param old_price: the old gas price params in case that we are trying to resubmit a transaction.
+        :param fallback_gas: (external) gas to spend when base_gas and safe_tx_gas are zero and no gas estimation is possible.
         :return: the raw Safe transaction
         """
         sender_address = ledger_api.api.toChecksumAddress(sender_address)
@@ -427,7 +429,10 @@ class GnosisSafeContract(Contract):
             refund_receiver,
             signatures,
         )
-        configured_gas = base_gas + safe_tx_gas + 75000
+        # see https://github.com/safe-global/safe-eth-py/blob/6c0e0d80448e5f3496d0d94985bca239df6eb399/gnosis/safe/safe_tx.py#L354
+        configured_gas = (
+            base_gas + safe_tx_gas + 75000 if base_gas != 0 or safe_tx_gas != 0 else 1
+        )
         tx_parameters: Dict[str, Union[str, int]] = {
             "from": sender_address,
             "gas": configured_gas,
@@ -450,13 +455,20 @@ class GnosisSafeContract(Contract):
             and max_priority_fee_per_gas is None
         ):
             tx_parameters.update(ledger_api.try_get_gas_pricing(old_price=old_price))
-        # note, the next line makes an eth_estimateGas call!
+        # note, the next line makes an eth_estimateGas call iff gas is not set!
         transaction_dict = w3_tx.buildTransaction(tx_parameters)
-        transaction_dict["gas"] = Wei(
-            max(transaction_dict["gas"] + 75000, configured_gas)
-        )
+        if configured_gas != 1:
+            transaction_dict["gas"] = Wei(configured_gas)
+        else:
+            gas_estimate = (
+                ledger_api._try_get_gas_estimate(  # pylint: disable=protected-access
+                    transaction_dict
+                )
+            )
+            transaction_dict["gas"] = (
+                Wei(gas_estimate) if gas_estimate is not None else fallback_gas
+            )
         transaction_dict["nonce"] = nonce  # pragma: nocover
-
         return transaction_dict
 
     @classmethod
@@ -640,3 +652,120 @@ class GnosisSafeContract(Contract):
         safe_contract = cls.get_instance(ledger_api, contract_address)
         safe_nonce = safe_contract.functions.nonce().call(block_identifier="latest")
         return dict(safe_nonce=safe_nonce)
+
+    @classmethod
+    def get_ingoing_transfers(
+        cls,
+        ledger_api: EthereumApi,
+        contract_address: str,
+        from_block: Optional[str] = None,
+        to_block: Optional[str] = "latest",
+    ) -> JSONLike:
+        """
+        A list of transfers into the contract.
+
+        :param ledger_api: the ledger API object
+        :param contract_address: the contract address,
+        :param from_block: from which block to start tje search
+        :param to_block: at which block to end the search
+        :return: list of transfers
+        """
+        safe_contract = cls.get_instance(ledger_api, contract_address)
+
+        if from_block is None:
+            logging.info(
+                "'from_block' not provided, checking for transfers to the safe contract in the last 50 blocks."
+            )
+            current_block = ledger_api.api.eth.get_block("latest")["number"]
+            from_block = hex(max(0, current_block - 50))  # check in the last ~10 min
+
+        safe_filter = safe_contract.events.SafeReceived.createFilter(
+            fromBlock=from_block, toBlock=to_block
+        )
+        all_entries = safe_filter.get_all_entries()
+
+        return {
+            "data": list(
+                map(
+                    lambda entry: {
+                        "sender": entry["args"]["sender"],
+                        "amount": int(entry["args"]["value"]),
+                        "blockNumber": entry["blockNumber"],
+                    },
+                    all_entries,
+                )
+            )
+        }
+
+    @classmethod
+    def get_balance(cls, ledger_api: EthereumApi, contract_address: str) -> JSONLike:
+        """
+        Retrieve the safe's balance
+
+        :param ledger_api: the ledger API object
+        :param contract_address: the contract address
+        :return: the safe balance (in wei)
+        """
+        return dict(balance=ledger_api.get_balance(address=contract_address))
+
+    @classmethod
+    def get_amount_spent(  # pylint: disable=unused-argument
+        cls,
+        ledger_api: EthereumApi,
+        contract_address: str,
+        tx_hash: str,
+    ) -> JSONLike:
+        """
+        Get the amount of ether spent in a tx.
+
+        :param ledger_api: the ledger API object
+        :param contract_address: the contract address (not used)
+        :param tx_hash: the settled tx hash
+        :return: the safe balance (in wei)
+        """
+        tx_receipt = ledger_api.get_transaction_receipt(tx_hash)
+        tx = ledger_api.get_transaction(tx_hash)
+
+        tx_value = int(tx["value"])
+        gas_price = int(tx["gasPrice"])
+        gas_used = int(tx_receipt["gasUsed"])
+        total_spent = tx_value + (gas_price * gas_used)
+
+        return dict(amount_spent=total_spent)
+
+    @classmethod
+    def get_safe_txs(
+        cls,
+        ledger_api: EthereumApi,
+        contract_address: str,
+        from_block: BlockIdentifier = "earliest",
+        to_block: BlockIdentifier = "latest",
+    ) -> JSONLike:
+        """
+        Get all the safe tx hashes.
+
+        :param ledger_api: the ledger API object
+        :param contract_address: the contract address (not used)
+        :param from_block: from which block to search for events
+        :param to_block: to which block to search for events
+         :return: the safe txs
+        """
+
+        ledger_api = cast(EthereumApi, ledger_api)
+        factory_contract = cls.get_instance(ledger_api, contract_address)
+        entries = factory_contract.events.ExecutionSuccess.createFilter(
+            fromBlock=from_block,
+            toBlock=to_block,
+        ).get_all_entries()
+
+        return dict(
+            txs=list(
+                map(
+                    lambda entry: dict(
+                        tx_hash=entry.transactionHash.hex(),
+                        block_number=entry.blockNumber,
+                    ),
+                    entries,
+                )
+            )
+        )
