@@ -1831,6 +1831,8 @@ class AbciApp(
     event_to_timeout: EventToTimeout = {}
     cross_period_persisted_keys: List[str] = []
 
+    _is_abstract: bool = True
+
     def __init__(
         self,
         synchronized_data: BaseSynchronizedData,
@@ -1853,6 +1855,11 @@ class AbciApp(
         self._timeouts = Timeouts[EventType]()
         self._reset_index = 0
 
+    @classmethod
+    def is_abstract(cls) -> bool:
+        """Return if the abci app is abstract."""
+        return cls._is_abstract
+
     @property
     def synchronized_data(self) -> BaseSynchronizedData:
         """Return the current synchronized data."""
