@@ -127,7 +127,7 @@ run_deployment_from_token  # unused function (autonomy/cli/deploy.py:189)
 DEFAULT_ACCOUNT  # unused variable (autonomy/test_tools/docker/registries.py:40)
 COMPONENT_REGISTRY  # unused variable (autonomy/test_tools/docker/registries.py:41)
 AGENT_REGISTRY  # unused variable (autonomy/test_tools/docker/registries.py:42)
-REGISTRIE_SMANAGER  # unused variable (autonomy/test_tools/docker/registries.py:43)
+REGISTRIES_MANAGER  # unused variable (autonomy/test_tools/docker/registries.py:43)
 GNOSIS_SAFE_MULTISIG  # unused variable (autonomy/test_tools/docker/registries.py:44)
 SERVICE_REGISTRY  # unused variable (autonomy/test_tools/docker/registries.py:45)
 SERVICE_MANAGER  # unused variable (autonomy/test_tools/docker/registries.py:46)
