@@ -22,8 +22,11 @@
 import pytest
 from aea.configurations.data_types import PublicId
 
-from tests.fixture_helpers import UseGnosisSafeHardHatNet
-from tests.test_agents.base import BaseTestEnd2EndExecution, RoundChecks
+from autonomy.test_tools.base_test_classes.agents import (
+    BaseTestEnd2EndExecution,
+    RoundChecks,
+)
+from autonomy.test_tools.fixture_helpers import UseGnosisSafeHardHatNet
 
 
 ipfs_daemon = pytest.mark.usefixtures("ipfs_daemon")
@@ -62,9 +65,13 @@ class BaseTestABCIAPYEstimationSkillNormalExecution(BaseTestEnd2EndExecution):
         },
         {
             "dotted_path": f"{__args_prefix}.round_timeout_seconds",
-            "value": 200,
+            "value": 300,
             "type_": "float",
         },
+        {
+            "dotted_path": f"{__args_prefix}.optimizer.timeout",
+            "value": 1,
+        },
     ]
 
 
@@ -83,6 +90,8 @@ class TestABCIAPYEstimationTwoAgents(
 ):
     """Test the ABCI apy_estimation_abci skill with two agents."""
 
+    wait_to_finish = 300
+
 
 @pytest.mark.parametrize("nb_nodes", (4,))
 class TestABCIAPYEstimationFourAgents(
@@ -91,4 +100,4 @@ class TestABCIAPYEstimationFourAgents(
 ):
     """Test the ABCI apy_estimation_abci skill with four agents."""
 
-    wait_to_finish = 300
+    wait_to_finish = 360
