@@ -24,9 +24,12 @@ import platform
 import shutil
 from pathlib import Path
 from typing import Tuple
+from unittest import mock
 
 import pytest
 
+from autonomy.analyse.abci.handlers import check_handlers
+
 from tests.conftest import ROOT_DIR
 from tests.test_autonomy.test_cli.base import BaseCliTest
 
@@ -91,9 +94,47 @@ class TestCheckHandlers(BaseCliTest):
         assert result.exit_code == 1
         assert "Common handler 'dummy' is not defined in" in result.output
 
+    def test_check_handlers_missing_handler(
+        self,
+    ) -> None:
+        """Test check-handlers command missing handler."""
+
+        # Since the CLI catches exceptions, to test for raises we need to call check_handlers directly
+        with pytest.raises(
+            ValueError,
+            match=r"Handler ABCIHandler declared in .* is missing from .*",
+        ):
+            # Mock dir() so module_attributes is = []
+            with mock.patch("autonomy.analyse.abci.handlers.dir", return_value=[]):
+                # Mock Path.relative_to() and return any valid module so import_module does not fail
+                with mock.patch("pathlib.Path.relative_to", return_value="pathlib"):
+                    check_handlers(
+                        Path(
+                            self.t,
+                            "packages",
+                            "valory",
+                            "skills",
+                            "abstract_abci",
+                            "skill.yaml",
+                        ),
+                        [],
+                        [],
+                    )
+
     @classmethod
     def teardown(cls) -> None:
         """Teardown method."""
 
         os.chdir(cls.cwd)
         super().teardown()
+
+
+def test_check_handlers_missing_file() -> None:
+    """Test check-handlers missing file."""
+
+    # Since the CLI catches exceptions, to test for raises we need to call check_handlers directly
+    with pytest.raises(FileNotFoundError, match="Handler file dummy does not exist"):
+        with mock.patch("pathlib.Path.relative_to", return_value="dummy"):
+            check_handlers(
+                config_file=Path("file", "dummy"), common_handlers=[], skip_skills=[]
+            )
