@@ -21,15 +21,16 @@
 
 
 import os
+import shutil
 from pathlib import Path
 from typing import Any, Tuple
 from unittest import mock
 
 from autonomy.cli import cli
 from autonomy.replay.agent import AgentRunner
+from autonomy.test_tools.docker.base import skip_docker_tests
 
 from tests.conftest import ROOT_DIR
-from tests.helpers.docker.base import skip_docker_tests
 from tests.test_autonomy.test_cli.base import BaseCliTest
 
 
@@ -89,7 +90,12 @@ class TestAgentRunner(BaseCliTest):
     def setup(cls) -> None:
         """Setup."""
         super().setup()
-        os.chdir(cls.t)
+
+        shutil.copytree(
+            cls.packages_dir / "valory" / "services" / "hello_world",
+            cls.t / "hello_world",
+        )
+        os.chdir(cls.t / "hello_world")
 
     def test_run(self) -> None:
         """Test run."""
@@ -100,15 +106,11 @@ class TestAgentRunner(BaseCliTest):
                 (
                     "deploy",
                     "build",
-                    "deployment",
-                    "valory/oracle_hardhat",
                     str(self.keys_path),
-                    "--packages-dir",
-                    str(self.packages_dir),
                     "--force",
                     "--local",
                     "--o",
-                    str(self.t),
+                    str(self.t / "abci_build"),
                 ),
             )
 
