@@ -41,6 +41,10 @@ from aea.mail.base import Envelope, Message
 from aea.protocols.dialogue.base import Dialogue as BaseDialogue
 from aea_ledger_ethereum import EthereumCrypto
 
+from autonomy.test_tools.configurations import ETHEREUM_KEY_DEPLOYER
+from autonomy.test_tools.docker.base import skip_docker_tests
+from autonomy.test_tools.docker.ganache import DEFAULT_GANACHE_CHAIN_ID
+
 from packages.valory.connections.ledger.connection import LedgerConnection
 from packages.valory.connections.ledger.ledger_dispatcher import (
     LedgerApiRequestDispatcher,
@@ -52,10 +56,6 @@ from packages.valory.protocols.ledger_api.dialogues import (
 )
 from packages.valory.protocols.ledger_api.message import LedgerApiMessage
 
-from tests.conftest import ETHEREUM_KEY_DEPLOYER
-from tests.helpers.docker.base import skip_docker_tests
-from tests.helpers.docker.ganache import DEFAULT_GANACHE_CHAIN_ID
-
 
 SOME_SKILL_ID = "some/skill:0.1.0"
 
@@ -101,8 +101,8 @@ class LedgerApiDialogues(BaseLedgerApiDialogues):
 
 @pytest.mark.usefixtures("ganache_scope_class")
 @skip_docker_tests
-class TestLedgerConnection:
-    """Tests for ledger connection."""
+class TestLedgerDispatcher:
+    """Tests for ledger dispatcher."""
 
     @pytest.mark.asyncio
     @ledger_ids
