@@ -22,15 +22,16 @@
 from pathlib import Path
 from typing import Any, Dict
 
+from autonomy.test_tools.base_test_classes.contracts import BaseGanacheContractTest
+from autonomy.test_tools.docker.base import skip_docker_tests
+
 from packages.valory.contracts.gnosis_safe.contract import SAFE_CONTRACT
 from packages.valory.contracts.gnosis_safe_proxy_factory.contract import (
     GnosisSafeProxyFactoryContract,
     PROXY_FACTORY_CONTRACT,
 )
 
-from tests.conftest import ROOT_DIR
-from tests.helpers.docker.base import skip_docker_tests
-from tests.test_contracts.base import BaseGanacheContractTest
+from tests.conftest import ROOT_DIR, THIRD_PARTY_CONTRACTS
 
 
 DEFAULT_GAS = 1000000
@@ -46,6 +47,7 @@ class TestGnosisSafeProxyFactory(BaseGanacheContractTest):
         ROOT_DIR, "packages", "valory", "contracts", "gnosis_safe_proxy_factory"
     )
     contract: GnosisSafeProxyFactoryContract
+    third_party_contract_dir: Path = THIRD_PARTY_CONTRACTS
 
     @classmethod
     def deployment_kwargs(cls) -> Dict[str, Any]:
