@@ -28,13 +28,15 @@ from aea.crypto.registries import crypto_registry
 from aea_ledger_ethereum import EthereumCrypto
 from web3 import Web3
 
+from autonomy.test_tools.base_test_classes.contracts import BaseGanacheContractTest
+from autonomy.test_tools.configurations import ETHEREUM_KEY_PATH_1
+from autonomy.test_tools.docker.base import skip_docker_tests
+
 from packages.valory.contracts.offchain_aggregator.contract import (
     OffchainAggregatorContract,
 )
 
-from tests.conftest import ETHEREUM_KEY_PATH_1, ROOT_DIR
-from tests.helpers.docker.base import skip_docker_tests
-from tests.test_contracts.base import BaseGanacheContractTest
+from tests.conftest import ROOT_DIR, THIRD_PARTY_CONTRACTS
 
 
 class BaseContractTest(BaseGanacheContractTest):
@@ -52,6 +54,7 @@ class BaseContractTest(BaseGanacheContractTest):
         ROOT_DIR, "packages", "valory", "contracts", "offchain_aggregator"
     )
     contract: OffchainAggregatorContract
+    third_party_contract_dir: Path = THIRD_PARTY_CONTRACTS
 
     @classmethod
     def deployment_kwargs(cls) -> Dict[str, Any]:
