@@ -33,6 +33,8 @@ from unittest.mock import MagicMock
 
 import pytest
 import pytz  # type: ignore  # pylint: disable=import-error
+from hypothesis import given
+from hypothesis import strategies as st
 
 from packages.valory.protocols.ledger_api.custom_types import (
     SignedTransaction,
@@ -46,6 +48,8 @@ except (ImportError, ModuleNotFoundError):
     pytestmark = pytest.mark.skip
 
 
+from autonomy.test_tools.helpers.base import try_send
+
 from packages.open_aea.protocols.signing import SigningMessage
 from packages.valory.connections.http_client.connection import HttpDialogues
 from packages.valory.protocols.http import HttpMessage
@@ -60,6 +64,7 @@ from packages.valory.skills.abstract_round_abci.behaviour_utils import (
     AsyncBehaviour,
     BaseBehaviour,
     DegenerateBehaviour,
+    GENESIS_TIME_FMT,
     HEIGHT_OFFSET_MULTIPLIER,
     MIN_HEIGHT_OFFSET,
     NON_200_RETURN_CODE_DURING_RESET_THRESHOLD,
@@ -77,8 +82,6 @@ from packages.valory.skills.abstract_round_abci.models import (
     _DEFAULT_TX_TIMEOUT,
 )
 
-from tests.helpers.base import try_send
-
 
 def yield_and_return_bool_wrapper(
     flag_value: bool,
@@ -1318,6 +1321,7 @@ class TestBaseBehaviour:
             ("nonce too low", RPCResponseStatus.INCORRECT_NONCE),
             ("insufficient funds", RPCResponseStatus.INSUFFICIENT_FUNDS),
             ("already known", RPCResponseStatus.ALREADY_KNOWN),
+            ("test", RPCResponseStatus.UNCLASSIFIED_ERROR),
         ),
     )
     @mock.patch.object(BaseBehaviour, "_send_transaction_signing_request")
@@ -1551,6 +1555,36 @@ class TestBaseBehaviour:
         self.behaviour._timeout = timeout
         assert self.behaviour._is_timeout_expired() == expiration_expected
 
+    @pytest.mark.parametrize("default", (True, False))
+    @given(st.datetimes(), st.integers(), st.integers())
+    def test_get_reset_params(
+        self, default: bool, timestamp: datetime, height: int, interval: int
+    ) -> None:
+        """Test `_get_reset_params` method."""
+        self.context_mock.state.round_sequence.last_round_transition_timestamp = (
+            timestamp
+        )
+        self.context_mock.state.round_sequence.last_round_transition_tm_height = height
+        self.behaviour.params.observation_interval = interval
+
+        actual = self.behaviour._get_reset_params(default)
+
+        if default:
+            assert actual is None
+
+        else:
+            offset = math.ceil(interval * HEIGHT_OFFSET_MULTIPLIER)
+            offset = max(MIN_HEIGHT_OFFSET, offset)
+            initial_height = str(height + offset)
+            genesis_time = timestamp.astimezone(pytz.UTC).strftime(GENESIS_TIME_FMT)
+
+            expected = [
+                ("genesis_time", genesis_time),
+                ("initial_height", initial_height),
+            ]
+
+            assert actual == expected
+
     @mock.patch.object(BaseBehaviour, "_start_reset")
     @mock.patch.object(BaseBehaviour, "_is_timeout_expired")
     def test_reset_tendermint_with_wait_timeout_expired(self, *_: mock.Mock) -> None:
