@@ -19,10 +19,9 @@
 
 """Test the models.py module of the skill."""
 
+from packages.valory.skills.abstract_round_abci.test_tools.base import DummyContext
 from packages.valory.skills.registration_abci.models import SharedState
 
-from tests.test_skills.base import DummyContext
-
 
 class TestSharedState:
     """Test SharedState(Model) class."""
