@@ -69,6 +69,7 @@ from packages.valory.skills.transaction_settlement_abci.behaviours import (
     CheckLateTxHashesBehaviour,
     CheckTransactionHistoryBehaviour,
     FinalizeBehaviour,
+    REVERT_CODES_TO_REASONS,
     RandomnessTransactionSubmissionBehaviour,
     ResetBehaviour,
     SelectKeeperTransactionSubmissionBehaviourA,
@@ -401,6 +402,83 @@ class TestTransactionSettlementBaseBehaviour(PriceEstimationFSMBehaviourBaseCase
             == expected_params
         )
 
+    def test_parse_revert_reason_successful(self) -> None:
+        """Test `_parse_revert_reason` method."""
+        # fast-forward to any behaviour of the tx settlement skill
+        self.fast_forward_to_behaviour(
+            behaviour=self.behaviour,
+            behaviour_id=SignatureBehaviour.behaviour_id,
+            synchronized_data=TransactionSettlementSynchronizedSata(
+                AbciAppDB(
+                    setup_data=AbciAppDB.data_to_lists(dict()),
+                )
+            ),
+        )
+
+        for code, explanation in REVERT_CODES_TO_REASONS.items():
+            message = MagicMock(
+                performative=ContractApiMessage.Performative.ERROR,
+                message=f"some text {code}.",
+            )
+
+            expected = f"Received a {code} revert error: {explanation}."
+
+            assert (
+                cast(
+                    TransactionSettlementBaseBehaviour, self.behaviour.current_behaviour
+                )._parse_revert_reason(message)
+                == expected
+            )
+
+    @pytest.mark.parametrize(
+        "message",
+        (
+            MagicMock(
+                performative=ContractApiMessage.Performative.ERROR,
+                message="Non existing code should be invalid GS086.",
+            ),
+            MagicMock(
+                performative=ContractApiMessage.Performative.ERROR,
+                message="Code not matching the regex should be invalid GS0265.",
+            ),
+            MagicMock(
+                performative=ContractApiMessage.Performative.ERROR,
+                message="No code in the message should be invalid.",
+            ),
+            MagicMock(
+                performative=ContractApiMessage.Performative.ERROR,
+                message="",  # empty message should be invalid
+            ),
+            MagicMock(
+                performative=ContractApiMessage.Performative.ERROR,
+                message=None,  # `None` message should be invalid
+            ),
+        ),
+    )
+    def test_parse_revert_reason_unsuccessful(
+        self, message: ContractApiMessage
+    ) -> None:
+        """Test `_parse_revert_reason` method."""
+        # fast-forward to any behaviour of the tx settlement skill
+        self.fast_forward_to_behaviour(
+            behaviour=self.behaviour,
+            behaviour_id=SignatureBehaviour.behaviour_id,
+            synchronized_data=TransactionSettlementSynchronizedSata(
+                AbciAppDB(
+                    setup_data=AbciAppDB.data_to_lists(dict()),
+                )
+            ),
+        )
+
+        expected = f"get_raw_safe_transaction unsuccessful! Received: {message}"
+
+        assert (
+            cast(
+                TransactionSettlementBaseBehaviour, self.behaviour.current_behaviour
+            )._parse_revert_reason(message)
+            == expected
+        )
+
 
 class TestRandomnessInOperation(BaseRandomnessBehaviourTest):
     """Test randomness in operation."""
