@@ -28,6 +28,8 @@ import pytest
 from aea_ledger_ethereum import EthereumApi
 from web3.types import RPCEndpoint, Wei
 
+from autonomy.test_tools.docker.base import skip_docker_tests
+
 from packages.open_aea.protocols.signing import SigningMessage
 from packages.open_aea.protocols.signing.custom_types import (
     RawTransaction,
@@ -42,6 +44,15 @@ from packages.valory.protocols.ledger_api.custom_types import (
     TransactionReceipt,
 )
 from packages.valory.skills.abstract_round_abci.base import AbciAppDB
+from packages.valory.skills.abstract_round_abci.test_tools.base import (
+    FSMBehaviourBaseCase,
+)
+from packages.valory.skills.abstract_round_abci.test_tools.integration import (
+    ExpectedContentType,
+    ExpectedTypesType,
+    HandlersType,
+    IntegrationBaseCase,
+)
 from packages.valory.skills.oracle_abci.behaviours import (
     OracleAbciAppConsensusBehaviour,
 )
@@ -49,6 +60,8 @@ from packages.valory.skills.oracle_deployment_abci.behaviours import (
     DeployOracleBehaviour,
 )
 from packages.valory.skills.price_estimation_abci.behaviours import (
+    ETHER_VALUE,
+    SAFE_TX_GAS,
     TransactionHashBehaviour,
 )
 from packages.valory.skills.price_estimation_abci.rounds import (
@@ -69,21 +82,13 @@ from packages.valory.skills.transaction_settlement_abci.payload_tools import (
 from packages.valory.skills.transaction_settlement_abci.rounds import (
     SynchronizedData as TxSettlementSynchronizedSata,
 )
-
-from tests.conftest import ROOT_DIR
-from tests.helpers.docker.base import skip_docker_tests
-from tests.test_skills.base import FSMBehaviourBaseCase
-from tests.test_skills.integration import (
-    ExpectedContentType,
-    ExpectedTypesType,
+from packages.valory.skills.transaction_settlement_abci.test_tools.integration import (
     GnosisIntegrationBaseCase,
-    HandlersType,
-    IntegrationBaseCase,
 )
 
+from tests.conftest import ROOT_DIR, THIRD_PARTY_CONTRACTS, make_ledger_api_connection
+
 
-SAFE_TX_GAS = 120000
-ETHER_VALUE = 0
 DUMMY_MAX_PRIORITY_FEE_PER_GAS = 3000000000
 DUMMY_MAX_FEE_PER_GAS = 4000000000
 DUMMY_REPRICING_MULTIPLIER = 1.1
@@ -102,6 +107,9 @@ class TransactionSettlementIntegrationBaseCase(
     """Base case for integration testing TransactionSettlement FSM Behaviour."""
 
     price_estimation_synchronized_data: PriceEstimationSynchronizedSata
+    ROOT_DIR = ROOT_DIR
+    make_ledger_api_connection_callable = make_ledger_api_connection
+    third_party_contract_dir: Path = THIRD_PARTY_CONTRACTS
 
     @classmethod
     def setup(cls, **kwargs: Any) -> None:
@@ -316,6 +324,32 @@ class TestRepricing(TransactionSettlementIntegrationBaseCase):
         assert self.hardhat_provider.make_request(
             RPCEndpoint("evm_setIntervalMining"), [mining_interval_msecs]
         ), "Re-enabling auto-mining failed!"
+        """
+        NOTE:
+        The second gas estimation will ALWAYS fail. That is, because the
+        current implementation of the plugin does not play well with Hardhat:
+        https://github.com/valory-xyz/open-aea/blob/main/plugins/aea-ledger-ethereum/aea_ledger_ethereum/ethereum.py#L1113-L1118
+        https://github.com/NomicFoundation/hardhat/blob/d1733f9ecfe8125111a707ff0e3dea287e584caa/packages/hardhat-core/src/internal/hardhat-network/provider/modules/eth.ts#L419-L424
+        eth_estimateGas
+          Contract call:       GnosisSafeProxy#<unrecognized-selector>
+          From:                0xbcd4042de499d14e55001ccbb24a551f3b954096
+          To:                  0x68fcdf52066cce5612827e872c45767e5a1f6551
+          Value:               0 ETH
+
+          Error: VM Exception while processing transaction: reverted with reason string 'GS026'
+              at GnosisSafeL2.checkNSignatures (third_party/safe-contracts/contracts/GnosisSafe.sol:301)
+              at GnosisSafeL2.checkSignatures (third_party/safe-contracts/contracts/GnosisSafe.sol:230)
+              at GnosisSafeL2.execTransaction (third_party/safe-contracts/contracts/GnosisSafe.sol:145)
+              at GnosisSafeL2.execTransaction (third_party/safe-contracts/contracts/GnosisSafeL2.sol:69)
+              at GnosisSafeProxy.<fallback> (third_party/safe-contracts/contracts/proxies/GnosisSafeProxy.sol:36)
+              at EthModule._estimateGasAction (/build/node_modules/hardhat/src/internal/hardhat-network/provider/modules/eth.ts:425:7)
+              at HardhatNetworkProvider._sendWithLogging (/build/node_modules/hardhat/src/internal/hardhat-network/provider/provider.ts:131:22)
+              at HardhatNetworkProvider.request (/build/node_modules/hardhat/src/internal/hardhat-network/provider/provider.ts:108:18)
+              at JsonRpcHandler._handleRequest (/build/node_modules/hardhat/src/internal/hardhat-network/jsonrpc/handler.ts:188:20)
+              at JsonRpcHandler._handleSingleRequest (/build/node_modules/hardhat/src/internal/hardhat-network/jsonrpc/handler.ts:167:17)
+              at Server.JsonRpcHandler.handleHttp (/build/node_modules/hardhat/src/internal/hardhat-network/jsonrpc/handler.ts:52:21)
+
+        """
         # send tx second time
         self.send_tx()
         # validate the tx
@@ -325,6 +359,9 @@ class TestRepricing(TransactionSettlementIntegrationBaseCase):
 class TestKeepers(OracleBehaviourBaseCase, IntegrationBaseCase):
     """Test the keepers related functionality for the tx settlement skill."""
 
+    ROOT_DIR = ROOT_DIR
+    make_ledger_api_connection_callable = make_ledger_api_connection
+
     @classmethod
     def setup(cls, **kwargs: Any) -> None:
         """Set up the test class."""
